/**************************************************************************
* This file is part of the WebIssues program
* Copyright (C) 2006 Michał Męciński
* Copyright (C) 2007-2008 WebIssues Team
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
**************************************************************************/

#ifndef PRECOMPILED_H
#define PRECOMPILED_H

#include <QtCore>
#include <QtGui>
#include <QtNetwork>

#include <QDomDocument>

#endif
